@@ -17,7 +17,7 @@
 """The share snapshots api."""
 
 from oslo_log import log
-import six
+from six.moves import http_client
 import webob
 from webob import exc
 
@@ -27,6 +27,7 @@ from manila.api.openstack import wsgi
 from manila.api.v1 import share_snapshots
 from manila.api.views import share_snapshots as snapshot_views
 from manila.common import constants
+from manila.db import api as db_api
 from manila import exception
 from manila.i18n import _
 from manila import share
@@ -46,7 +47,7 @@ class ShareSnapshotsController(share_snapshots.ShareSnapshotMixin,
         self.share_api = share.API()
 
     @wsgi.Controller.authorize('unmanage_snapshot')
-    def _unmanage(self, req, id, body=None):
+    def _unmanage(self, req, id, body=None, allow_dhss_true=False):
         """Unmanage a share snapshot."""
         context = req.environ['manila.context']
 
@@ -56,7 +57,7 @@ class ShareSnapshotsController(share_snapshots.ShareSnapshotMixin,
             snapshot = self.share_api.get_snapshot(context, id)
 
             share = self.share_api.get(context, snapshot['share_id'])
-            if share.get('share_server_id'):
+            if not allow_dhss_true and share.get('share_server_id'):
                 msg = _("Operation 'unmanage_snapshot' is not supported for "
                         "snapshots of shares that are created with share"
                         " servers (created with share-networks).")
@@ -75,9 +76,9 @@ class ShareSnapshotsController(share_snapshots.ShareSnapshotMixin,
 
             self.share_api.unmanage_snapshot(context, snapshot, share['host'])
         except (exception.ShareSnapshotNotFound, exception.ShareNotFound) as e:
-            raise exc.HTTPNotFound(explanation=six.text_type(e))
+            raise exc.HTTPNotFound(explanation=e)
 
-        return webob.Response(status_int=202)
+        return webob.Response(status_int=http_client.ACCEPTED)
 
     @wsgi.Controller.authorize('manage_snapshot')
     def _manage(self, req, body):
@@ -127,10 +128,10 @@ class ShareSnapshotsController(share_snapshots.ShareSnapshotMixin,
             snapshot_ref = self.share_api.manage_snapshot(context, snapshot,
                                                           driver_options)
         except (exception.ShareNotFound, exception.ShareSnapshotNotFound) as e:
-            raise exc.HTTPNotFound(explanation=six.text_type(e))
+            raise exc.HTTPNotFound(explanation=e)
         except (exception.InvalidShare,
                 exception.ManageInvalidShareSnapshot) as e:
-            raise exc.HTTPConflict(explanation=six.text_type(e))
+            raise exc.HTTPConflict(explanation=e)
 
         return self._view_builder.detail(req, snapshot_ref)
 
@@ -162,6 +163,13 @@ class ShareSnapshotsController(share_snapshots.ShareSnapshotMixin,
                 msg = _("Required parameter %s is empty.") % parameter
                 raise exc_response(explanation=msg)
 
+    def _check_if_share_share_network_is_active(self, context, snapshot):
+        share_network_id = snapshot['share'].get('share_network_id')
+        if share_network_id:
+            share_network = db_api.share_network_get(
+                context, share_network_id)
+            common.check_share_network_is_active(share_network)
+
     def _allow(self, req, id, body, enable_ipv6=False):
         context = req.environ['manila.context']
 
@@ -184,6 +192,8 @@ class ShareSnapshotsController(share_snapshots.ShareSnapshotMixin,
 
         snapshot = self.share_api.get_snapshot(context, id)
 
+        self._check_if_share_share_network_is_active(context, snapshot)
+
         self._check_mount_snapshot_support(context, snapshot)
 
         try:
@@ -212,6 +222,8 @@ class ShareSnapshotsController(share_snapshots.ShareSnapshotMixin,
 
         self._check_mount_snapshot_support(context, snapshot)
 
+        self._check_if_share_share_network_is_active(context, snapshot)
+
         access = self.share_api.snapshot_access_get(context, access_id)
 
         if access['share_snapshot_id'] != snapshot['id']:
@@ -220,7 +232,7 @@ class ShareSnapshotsController(share_snapshots.ShareSnapshotMixin,
             raise webob.exc.HTTPBadRequest(explanation=msg)
 
         self.share_api.snapshot_deny_access(context, snapshot, access)
-        return webob.Response(status_int=202)
+        return webob.Response(status_int=http_client.ACCEPTED)
 
     def _check_mount_snapshot_support(self, context, snapshot):
         share = self.share_api.get(context, snapshot['share_id'])
@@ -265,11 +277,17 @@ class ShareSnapshotsController(share_snapshots.ShareSnapshotMixin,
     def manage(self, req, body):
         return self._manage(req, body)
 
-    @wsgi.Controller.api_version('2.12')
+    @wsgi.Controller.api_version('2.12', '2.48')
     @wsgi.action('unmanage')
     def unmanage(self, req, id, body=None):
         return self._unmanage(req, id, body)
 
+    @wsgi.Controller.api_version('2.49')  # noqa
+    @wsgi.action('unmanage')
+    def unmanage(self, req, id,   # pylint: disable=function-redefined  # noqa F811
+                 body=None):
+        return self._unmanage(req, id, body, allow_dhss_true=True)
+
     @wsgi.Controller.api_version('2.32')
     @wsgi.action('allow_access')
     @wsgi.response(202)
