@@ -443,8 +443,9 @@ class CephFSDriver(driver.ExecuteMixin, driver.GaneshaMixin,
             "sub_name": share["id"],
             "size": size,
             "namespace_isolated": True,
-            "mode": self._cephfs_volume_mode,
+            "mode": self._cephfs_volume_mode
         }
+
         if share['share_group_id'] is not None:
             argdict.update({"group_name": share["share_group_id"]})
 
@@ -518,8 +519,14 @@ class CephFSDriver(driver.ExecuteMixin, driver.GaneshaMixin,
             share_server=share_server)
 
     def ensure_share(self, context, share, share_server=None):
-        # Creation is idempotent
-        return self.create_share(context, share, share_server)
+        try:
+            export_location = self._get_export_locations(share)
+        except exception.ShareBackendException as e:
+            if 'does not exist' in str(e).lower():
+                raise exception.ShareResourceNotFound(share_id=share['id'])
+            raise
+
+        return export_location
 
     def extend_share(self, share, new_size, share_server=None):
         # resize FS subvolume/share
@@ -1048,7 +1055,8 @@ class NFSProtocolHelper(ganesha.GaneshaNASHelper2):
         return {
             'Name': 'Ceph',
             'User_Id': ceph_auth_id,
-            'Secret_Access_Key': auth_result
+            'Secret_Access_Key': auth_result,
+            'Filesystem': self.volname
         }
 
     def _cleanup_fsal_hook(self, base, share, access):
