@@ -31,50 +31,39 @@ LOG = log.getLogger(__name__)
 
 hitachi_hnas_opts = [
     cfg.HostAddressOpt('hitachi_hnas_ip',
-                       deprecated_name='hds_hnas_ip',
                        help="HNAS management interface IP for communication "
                             "between Manila controller and HNAS."),
     cfg.StrOpt('hitachi_hnas_user',
-               deprecated_name='hds_hnas_user',
                help="HNAS username Base64 String in order to perform tasks "
                     "such as create file-systems and network interfaces."),
     cfg.StrOpt('hitachi_hnas_password',
-               deprecated_name='hds_hnas_password',
                secret=True,
                help="HNAS user password. Required only if private key is not "
                     "provided."),
     cfg.IntOpt('hitachi_hnas_evs_id',
-               deprecated_name='hds_hnas_evs_id',
                help="Specify which EVS this backend is assigned to."),
     cfg.HostAddressOpt('hitachi_hnas_evs_ip',
-                       deprecated_name='hds_hnas_evs_ip',
                        help="Specify IP for mounting shares."),
     cfg.HostAddressOpt('hitachi_hnas_admin_network_ip',
                        help="Specify IP for mounting shares in the Admin "
                             "network."),
     cfg.StrOpt('hitachi_hnas_file_system_name',
-               deprecated_name='hds_hnas_file_system_name',
                help="Specify file-system name for creating shares."),
     cfg.StrOpt('hitachi_hnas_ssh_private_key',
-               deprecated_name='hds_hnas_ssh_private_key',
                secret=True,
                help="RSA/DSA private key value used to connect into HNAS. "
                     "Required only if password is not provided."),
     cfg.HostAddressOpt('hitachi_hnas_cluster_admin_ip0',
-                       deprecated_name='hds_hnas_cluster_admin_ip0',
                        help="The IP of the clusters admin node. Only set in "
                             "HNAS multinode clusters."),
     cfg.IntOpt('hitachi_hnas_stalled_job_timeout',
-               deprecated_name='hds_hnas_stalled_job_timeout',
                default=30,
                help="The time (in seconds) to wait for stalled HNAS jobs "
                     "before aborting."),
     cfg.StrOpt('hitachi_hnas_driver_helper',
-               deprecated_name='hds_hnas_driver_helper',
                default='manila.share.drivers.hitachi.hnas.ssh.HNASSSHBackend',
                help="Python class to be used for driver helper."),
     cfg.BoolOpt('hitachi_hnas_allow_cifs_snapshot_while_mounted',
-                deprecated_name='hds_hnas_allow_cifs_snapshot_while_mounted',
                 default=False,
                 help="By default, CIFS snapshots are not allowed to be taken "
                      "when the share has clients connected because consistent "
@@ -310,7 +299,7 @@ class HitachiHNASDriver(driver.ShareDriver):
                                        is_snapshot=is_snapshot)
 
     def create_share(self, context, share, share_server=None):
-        """Creates share.
+        r"""Creates share.
 
         :param context: The `context.RequestContext` object for the request
         :param share: Share that will be created.
@@ -448,8 +437,8 @@ class HitachiHNASDriver(driver.ShareDriver):
                  {'id': snapshot['id']})
 
     def create_share_from_snapshot(self, context, share, snapshot,
-                                   share_server=None):
-        """Creates a new share from snapshot.
+                                   share_server=None, parent_share=None):
+        r"""Creates a new share from snapshot.
 
         :param context: The `context.RequestContext` object for the request
         :param share: Information about the new share.
@@ -521,7 +510,7 @@ class HitachiHNASDriver(driver.ShareDriver):
         return export_list
 
     def ensure_share(self, context, share, share_server=None):
-        """Ensure that share is exported.
+        r"""Ensure that share is exported.
 
         :param context: The `context.RequestContext` object for the request
         :param share: Share that will be checked.
@@ -623,6 +612,8 @@ class HitachiHNASDriver(driver.ShareDriver):
         total_space, free_space, dedupe = self.hnas.get_stats()
 
         reserved = self.configuration.safe_get('reserved_share_percentage')
+        reserved_snapshot = self.configuration.safe_get(
+            'reserved_share_from_snapshot_percentage') or reserved
 
         data = {
             'share_backend_name': self.backend_name,
@@ -633,6 +624,7 @@ class HitachiHNASDriver(driver.ShareDriver):
             'total_capacity_gb': total_space,
             'free_capacity_gb': free_space,
             'reserved_percentage': reserved,
+            'reserved_snapshot_percentage': reserved_snapshot,
             'qos': False,
             'thin_provisioning': True,
             'dedupe': dedupe,
@@ -646,7 +638,7 @@ class HitachiHNASDriver(driver.ShareDriver):
         super(HitachiHNASDriver, self)._update_share_stats(data)
 
     def manage_existing(self, share, driver_options):
-        """Manages a share that exists on backend.
+        r"""Manages a share that exists on backend.
 
         :param share: Share that will be managed.
         :param driver_options: Empty dict or dict with 'volume_id' option.
@@ -1168,7 +1160,7 @@ class HitachiHNASDriver(driver.ShareDriver):
         return export_list
 
     def _get_export_path(self, ip, share_proto, hnas_id, is_snapshot):
-        """Gets and returns export path.
+        r"""Gets and returns export path.
 
         :param ip: IP from HNAS EVS configured.
         :param share_proto: Share or snapshot protocol (NFS or CIFS).
@@ -1223,7 +1215,7 @@ class HitachiHNASDriver(driver.ShareDriver):
         return export_list
 
     def ensure_snapshot(self, context, snapshot, share_server=None):
-        """Ensure that snapshot is exported.
+        r"""Ensure that snapshot is exported.
 
         :param context: The `context.RequestContext` object for the request.
         :param snapshot: Snapshot that will be checked.
