@@ -82,7 +82,7 @@ class FPG(types.String, types.IPAddress):
         self.max_ip = max_ip
 
     def __call__(self, value):
-        if value is None or value.strip(' ') is '':
+        if value is None or value.strip(' ') == '':
             message = _("Invalid configuration. hpe3par_fpg must be set.")
             LOG.error(message)
             raise exception.HPE3ParInvalid(err=message)
@@ -117,70 +117,57 @@ class FPG(types.String, types.IPAddress):
     def _formatter(self, value):
         return six.text_type(value)
 
+
 HPE3PAR_OPTS = [
     cfg.StrOpt('hpe3par_api_url',
                default='',
                help="3PAR WSAPI Server Url like "
-                    "https://<3par ip>:8080/api/v1",
-               deprecated_name='hp3par_api_url'),
+                    "https://<3par ip>:8080/api/v1"),
     cfg.StrOpt('hpe3par_username',
                default='',
-               help="3PAR username with the 'edit' role",
-               deprecated_name='hp3par_username'),
+               help="3PAR username with the 'edit' role"),
     cfg.StrOpt('hpe3par_password',
                default='',
                help="3PAR password for the user specified in hpe3par_username",
-               secret=True,
-               deprecated_name='hp3par_password'),
+               secret=True),
     cfg.HostAddressOpt('hpe3par_san_ip',
-                       help="IP address of SAN controller",
-                       deprecated_name='hp3par_san_ip'),
+                       help="IP address of SAN controller"),
     cfg.StrOpt('hpe3par_san_login',
                default='',
-               help="Username for SAN controller",
-               deprecated_name='hp3par_san_login'),
+               help="Username for SAN controller"),
     cfg.StrOpt('hpe3par_san_password',
                default='',
                help="Password for SAN controller",
-               secret=True,
-               deprecated_name='hp3par_san_password'),
+               secret=True),
     cfg.PortOpt('hpe3par_san_ssh_port',
                 default=22,
-                help='SSH port to use with SAN',
-                deprecated_name='hp3par_san_ssh_port'),
+                help='SSH port to use with SAN'),
     cfg.MultiOpt('hpe3par_fpg',
                  item_type=FPG(min_ip=0, max_ip=FPG.MAX_SUPPORTED_IP_PER_VFS),
-                 help="The File Provisioning Group (FPG) to use",
-                 deprecated_name='hp3par_fpg'),
+                 help="The File Provisioning Group (FPG) to use"),
     cfg.BoolOpt('hpe3par_fstore_per_share',
                 default=False,
-                help="Use one filestore per share",
-                deprecated_name='hp3par_fstore_per_share'),
+                help="Use one filestore per share"),
     cfg.BoolOpt('hpe3par_require_cifs_ip',
                 default=False,
                 help="Require IP access rules for CIFS (in addition to user)"),
     cfg.BoolOpt('hpe3par_debug',
                 default=False,
-                help="Enable HTTP debugging to 3PAR",
-                deprecated_name='hp3par_debug'),
+                help="Enable HTTP debugging to 3PAR"),
     cfg.StrOpt('hpe3par_cifs_admin_access_username',
                default='',
-               help="File system admin user name for CIFS.",
-               deprecated_name='hp3par_cifs_admin_access_username'),
+               help="File system admin user name for CIFS."),
     cfg.StrOpt('hpe3par_cifs_admin_access_password',
                default='',
                help="File system admin password for CIFS.",
-               secret=True,
-               deprecated_name='hp3par_cifs_admin_access_password'),
+               secret=True),
     cfg.StrOpt('hpe3par_cifs_admin_access_domain',
                default='LOCAL_CLUSTER',
-               help="File system domain for the CIFS admin user.",
-               deprecated_name='hp3par_cifs_admin_access_domain'),
+               help="File system domain for the CIFS admin user."),
     cfg.StrOpt('hpe3par_share_mount_path',
                default='/mnt/',
                help="The path where shares will be mounted when deleting "
-                    "nested file trees.",
-               deprecated_name='hpe3par_share_mount_path'),
+                    "nested file trees."),
 ]
 
 CONF = cfg.CONF
@@ -473,7 +460,7 @@ class HPE3ParShareDriver(driver.ShareDriver):
             'now': datetime.datetime.now().strftime('%H%M%S'),
         }
 
-        acceptable = re.compile('[^a-zA-Z0-9_=:@# \-]+', re.UNICODE)
+        acceptable = re.compile(r'[^a-zA-Z0-9_=:@# \-]+', re.UNICODE)
         comment = ("OpenStack Manila - host=%(host)s  orig_name=%(name)s "
                    "created=%(now)s" % info)
 
@@ -500,7 +487,7 @@ class HPE3ParShareDriver(driver.ShareDriver):
         return self._hpe3par.build_export_locations(protocol, ips, path)
 
     def create_share_from_snapshot(self, context, share, snapshot,
-                                   share_server=None):
+                                   share_server=None, parent_share=None):
         """Is called to create share from snapshot."""
 
         fpg, vfs, ips = self._get_pool_location(share, share_server)
@@ -619,6 +606,11 @@ class HPE3ParShareDriver(driver.ShareDriver):
         if reserved_share_percentage is None:
             reserved_share_percentage = 0
 
+        reserved_share_from_snapshot_percentage = self.configuration.safe_get(
+            'reserved_share_from_snapshot_percentage')
+        if reserved_share_from_snapshot_percentage is None:
+            reserved_share_from_snapshot_percentage = reserved_share_percentage
+
         stats = {
             'share_backend_name': backend_name,
             'driver_handles_share_servers': self.driver_handles_share_servers,
@@ -629,6 +621,8 @@ class HPE3ParShareDriver(driver.ShareDriver):
             'free_capacity_gb': 0,
             'provisioned_capacity_gb': 0,
             'reserved_percentage': reserved_share_percentage,
+            'reserved_snapshot_percentage':
+                reserved_share_from_snapshot_percentage,
             'max_over_subscription_ratio': max_over_subscription_ratio,
             'qos': False,
             'thin_provisioning': True,  # 3PAR default is thin
@@ -642,6 +636,8 @@ class HPE3ParShareDriver(driver.ShareDriver):
             for fpg in self.fpgs:
                 fpg_status = self._hpe3par.get_fpg_status(fpg)
                 fpg_status['reserved_percentage'] = reserved_share_percentage
+                fpg_status['reserved_snapshot_percentage'] = (
+                    reserved_share_from_snapshot_percentage)
                 LOG.debug("FPG status = %s.", fpg_status)
                 stats.setdefault('pools', []).append(fpg_status)
 
