@@ -27,6 +27,7 @@ from manila.share import configuration
 from manila.share.drivers.container import driver
 from manila.share.drivers.container import protocol_helper
 from manila import test
+from manila.tests import db_utils
 from manila.tests import fake_utils
 from manila.tests.share.drivers.container import fakes as cont_fakes
 
@@ -101,6 +102,8 @@ class ContainerShareDriverTestCase(test.TestCase):
         self.assertEqual('Docker', self._driver._stats['share_backend_name'])
         self.assertEqual('CIFS', self._driver._stats['storage_protocol'])
         self.assertEqual(0, self._driver._stats['reserved_percentage'])
+        self.assertEqual(0,
+                         self._driver._stats['reserved_snapshot_percentage'])
         self.assertIsNone(self._driver._stats['consistency_group_support'])
         self.assertEqual(False, self._driver._stats['snapshot_support'])
         self.assertEqual('ContainerShareDriver',
@@ -522,3 +525,195 @@ class ContainerShareDriverTestCase(test.TestCase):
         mock_container_exists.assert_called_once_with(
             fake_name
         )
+
+    def test_migration_complete(self):
+        share_server = {'id': 'fakeid'}
+        fake_container_name = 'manila_fake_container'
+        new_export_location = 'new_export_location'
+
+        mock_migraton_storage = self.mock_object(self._driver.storage,
+                                                 'migration_complete')
+        mock_get_container_name = self.mock_object(
+            self._driver, '_get_container_name',
+            mock.Mock(return_value=fake_container_name))
+
+        mock_mount = self.mock_object(
+            self._driver, '_mount_storage',
+            mock.Mock(return_value=new_export_location))
+
+        mock_umount = self.mock_object(self._driver, '_umount_storage')
+
+        expected_location = {'export_locations': new_export_location}
+        self.assertEqual(expected_location,
+                         self._driver.migration_complete(
+                             self._context, self.share, self.share, None,
+                             None, share_server, share_server))
+
+        mock_migraton_storage.assert_called_once_with(
+            self._context, self.share, self.share, None, None,
+            destination_share_server=share_server, share_server=share_server
+        )
+        mock_mount.assert_called_once_with(
+            self.share, fake_container_name, self.share.share_id
+        )
+        mock_umount.assert_called_once_with(
+            self.share, fake_container_name, self.share.share_id
+        )
+        mock_get_container_name.assert_called_with(
+            share_server['id']
+        )
+
+    def test_share_server_migration_complete(self):
+        source_server = {'id': 'source_fake_id', 'host': 'host@back1'}
+        dest_server = {'id': 'dest_fake_id', 'host': 'host@back2'}
+        fake_container_name = 'manila_fake_container'
+        new_export_location = 'new_export_location'
+        fake_pool_name = 'fake_vg'
+        shares_list = [self.share, self.share]
+
+        mock_get_container_name = self.mock_object(
+            self._driver, '_get_container_name',
+            mock.Mock(return_value=fake_container_name))
+        mock_umount = self.mock_object(self._driver, '_umount_storage')
+        mock_migraton_storage = self.mock_object(
+            self._driver.storage, 'share_server_migration_complete')
+        mock_mount = self.mock_object(
+            self._driver, '_mount_storage',
+            mock.Mock(return_value=new_export_location))
+        mock_get_pool = self.mock_object(
+            self._driver.storage, 'get_share_pool_name',
+            mock.Mock(return_value=fake_pool_name))
+
+        share_updates = {}
+        for fake_share in shares_list:
+            share_updates[fake_share['id']] = {
+                'export_locations': new_export_location,
+                'pool_name': fake_pool_name,
+            }
+
+        expected_result = {
+            'share_updates': share_updates,
+        }
+        self.assertDictEqual(expected_result,
+                             self._driver.share_server_migration_complete(
+                                 self._context, source_server, dest_server,
+                                 shares_list, None, None))
+        mock_migraton_storage.assert_called_once_with(
+            self._context, source_server, dest_server, shares_list, None, None)
+
+        # assert shares
+        for fake_share in shares_list:
+            mock_get_pool.assert_any_call(fake_share['share_id'])
+            mock_umount.assert_any_call(fake_share, fake_container_name,
+                                        fake_share.share_id)
+            mock_mount.assert_any_call(fake_share, fake_container_name,
+                                       fake_share.share_id)
+
+        mock_get_container_name.assert_any_call(source_server['id'])
+        mock_get_container_name.assert_any_call(dest_server['id'])
+
+    def test__get_different_security_service_keys(self):
+        sec_service_keys = ['dns_ip', 'server', 'domain', 'user', 'password',
+                            'ou']
+        current_security_service = {}
+        [current_security_service.update({key: key + '_1'})
+         for key in sec_service_keys]
+        new_security_service = {}
+        [new_security_service.update({key: key + '_2'})
+         for key in sec_service_keys]
+
+        db_utils.create_security_service(**current_security_service)
+        db_utils.create_security_service(**new_security_service)
+
+        different_keys = self._driver._get_different_security_service_keys(
+            current_security_service, new_security_service)
+
+        [self.assertIn(key, different_keys) for key in sec_service_keys]
+
+    @ddt.data(
+        (['dns_ip', 'server', 'domain', 'user', 'password', 'ou'], False),
+        (['user', 'password'], True)
+    )
+    @ddt.unpack
+    def test__check_if_all_fields_are_updatable(self, keys, expected_result):
+
+        current_security_service = db_utils.create_security_service()
+        new_security_service = db_utils.create_security_service()
+
+        mock_get_keys = self.mock_object(
+            self._driver, '_get_different_security_service_keys',
+            mock.Mock(return_value=keys))
+
+        result = self._driver._check_if_all_fields_are_updatable(
+            current_security_service, new_security_service)
+
+        self.assertEqual(expected_result, result)
+        mock_get_keys.assert_called_once_with(
+            current_security_service, new_security_service
+        )
+
+    @ddt.data(True, False)
+    def test_update_share_server_security_service(
+            self, with_current_service):
+        new_security_service = db_utils.create_security_service()
+        current_security_service = (
+            db_utils.create_security_service()
+            if with_current_service else None)
+        share_server = db_utils.create_share_server()
+        fake_container_name = 'fake_name'
+        network_info = {}
+        share_instances = []
+        share_instance_access_rules = []
+
+        mock_check_update = self.mock_object(
+            self._driver, 'check_update_share_server_security_service',
+            mock.Mock(return_value=True))
+        mock_get_container_name = self.mock_object(
+            self._driver, '_get_container_name',
+            mock.Mock(return_value=fake_container_name))
+        mock_setup = self.mock_object(self._driver, 'setup_security_services')
+        mock_update_sec_service = self.mock_object(
+            self._driver.security_service_helper, 'update_security_service')
+
+        self._driver.update_share_server_security_service(
+            self._context, share_server, network_info, share_instances,
+            share_instance_access_rules, new_security_service,
+            current_security_service=current_security_service)
+
+        mock_check_update.assert_called_once_with(
+            self._context, share_server, network_info, share_instances,
+            share_instance_access_rules, new_security_service,
+            current_security_service=current_security_service
+        )
+        mock_get_container_name.assert_called_once_with(share_server['id'])
+        if with_current_service:
+            mock_update_sec_service.assert_called_once_with(
+                fake_container_name, current_security_service,
+                new_security_service)
+        else:
+            mock_setup.assert_called_once_with(
+                fake_container_name, [new_security_service])
+
+    def test_update_share_server_security_service_not_supported(self):
+        new_security_service = db_utils.create_security_service()
+        current_security_service = db_utils.create_security_service()
+        share_server = db_utils.create_share_server()
+        share_instances = []
+        share_instance_access_rules = []
+        network_info = {}
+
+        mock_check_update = self.mock_object(
+            self._driver, 'check_update_share_server_security_service',
+            mock.Mock(return_value=False))
+
+        self.assertRaises(
+            exception.ManilaException,
+            self._driver.update_share_server_security_service,
+            self._context, share_server, network_info, share_instances,
+            share_instance_access_rules, new_security_service,
+            current_security_service=current_security_service)
+
+        mock_check_update.assert_called_once_with(
+            self._context, share_server, network_info, share_instances,
+            share_instance_access_rules, new_security_service,
+            current_security_service=current_security_service)
